@@ -98,7 +98,7 @@ const FILENAME_COPY_COUNTER_CLOSING_BRACKETS: &str = ")";
 pub const FILENAME_COPY_COUNTER_MAX: usize = 400;
 
 /// File extension of new _Tp-Note_ files.
-pub const FILENAME_EXTENSION_DEFAULT: &str = "md";
+pub const FILENAME_EXTENSION_DEFAULT: &str = "txt";
 
 /// The variables `FILENAME_EXTENSIONSS_*` list file extensions that Tp-Note
 /// considers as its own note files.
@@ -112,7 +112,7 @@ pub const FILENAME_EXTENSION_DEFAULT: &str = "md";
 ///
 /// The present list contains file extensions of
 /// Markdown encoded Tp-Note files.
-pub const FILENAME_EXTENSIONS_MD: &[&str] = &["md", "markdown", "markdn", "mdown", "mdtxt"];
+pub const FILENAME_EXTENSIONS_MD: &[&str] = &["txt", "md", "markdown", "markdn", "mdown", "mdtxt"];
 
 /// The present list contains file extensions of
 /// RestructuredText encoded Tp-Note files.
@@ -388,7 +388,9 @@ const APP_ARGS_EDITOR: &[&[&str]] = &[
         "com.github.marktext.marktext",
         "--new-window",
     ],
-    &["typora"],
+    // Disable Typora until bug fix:
+    // https://github.com/typora/typora-issues/issues/4633
+    //    &["typora"],
     &["retext"],
     &["geany", "-s", "-i", "-m"],
     &["gedit", "-w"],
@@ -399,7 +401,9 @@ const APP_ARGS_EDITOR: &[&[&str]] = &[
 ];
 #[cfg(target_family = "windows")]
 const APP_ARGS_EDITOR: &[&[&str]] = &[
-    &["C:\\Program Files\\Typora\\Typora.exe"],
+    // Disable Typora until bug fix:
+    // https://github.com/typora/typora-issues/issues/4633
+    //    &["C:\\Program Files\\Typora\\Typora.exe"],
     &[
         "C:\\Program Files\\Mark Text\\Mark Text.exe",
         "--new-window",
@@ -459,7 +463,7 @@ const VIEWER_STARTUP_DELAY: isize = 500;
 /// When set to true, the viewer feature is automatically disabled when
 /// _Tp-Note_ encounters an `.md` file without header.  Experienced users can
 /// set this to `true`.
-const VIEWER_MISSING_HEADER_DISABLES: bool = false;
+const VIEWER_MISSING_HEADER_DISABLES: bool = true;
 
 /// How often should the file watcher check for changes?
 /// Delay in milliseconds.
@@ -947,8 +951,7 @@ fn config_load_path(config_path: &Path) -> Result<Cfg, FileError> {
         // First check passed.
         Ok(config)
     } else {
-        #[allow(clippy::or_fun_call)]
-        fs::create_dir_all(config_path.parent().unwrap_or(Path::new("")))?;
+        fs::create_dir_all(config_path.parent().unwrap_or_else(|| Path::new("")))?;
 
         let mut buffer = File::create(config_path)?;
         buffer.write_all(toml::to_string_pretty(&Cfg::default())?.as_bytes())?;
