@@ -1,4 +1,5 @@
 #![windows_subsystem = "windows"]
+#![allow(clippy::vec_init_then_push)]
 //! _Tp-Note_ is a note taking tool and a template system, that consistently
 //! synchronizes the note's metadata with its filename. _Tp-Note_ collects
 //! various information about its environment and the clipboard and stores them
@@ -28,7 +29,6 @@ mod settings;
 mod viewer;
 mod workflow;
 
-extern crate semver;
 #[cfg(feature = "message-box")]
 use crate::alert_service::AlertService;
 use crate::config::backup_config_file;
@@ -60,7 +60,7 @@ const VERSION: Option<&'static str> = option_env!("CARGO_PKG_VERSION");
 ///    const MIN_CONFIG_FILE_VERSION: Option<&'static str> = Some("1.5.1");
 ///    ```
 ///
-/// 2. Require the config file to be of the same version as this binary. Abort if not satisfied.
+/// 2. Require the config file to be of the same version as this binary.
 ///
 ///    ```no_run
 ///    const MIN_CONFIG_FILE_VERSION: Option<&'static str> = VERSION;
@@ -72,7 +72,7 @@ const VERSION: Option<&'static str> = option_env!("CARGO_PKG_VERSION");
 ///    const MIN_CONFIG_FILE_VERSION: Option<&'static str> = None;
 ///    ```
 ///
-const MIN_CONFIG_FILE_VERSION: Option<&'static str> = Some("1.13.7");
+const MIN_CONFIG_FILE_VERSION: Option<&'static str> = VERSION;
 /// Authors.
 const AUTHOR: Option<&str> = option_env!("CARGO_PKG_AUTHORS");
 /// Copyright.
@@ -199,7 +199,7 @@ fn main() {
             ),
         };
 
-        let mut msg = serde_yaml::to_string(&about).unwrap_or("unknown".to_string());
+        let mut msg = serde_yaml::to_string(&about).unwrap_or_else(|_| "unknown".to_string());
         msg.push_str("---");
 
         // Print on console.
